@@ -1,5 +1,5 @@
-# Copyright (c) 2003-2009 Sylvain Thenault (thenault@gmail.com).
-# Copyright (c) 2003-2009 LOGILAB S.A. (Paris, FRANCE).
+# Copyright (c) 2003-2010 Sylvain Thenault (thenault@gmail.com).
+# Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
 # http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -152,10 +152,6 @@ should be a base name, not a path. You may set this option multiple times.'}),
                 {'default': True, 'type' : 'yn', 'metavar' : '<y_or_n>',
                  'help' : 'Pickle collected data for later comparisons.'}),
 
-               ('cache-size',
-                {'default': 500, 'type' : 'int', 'metavar': '<size>',
-                 'help' : 'Set the cache size for astng objects.'}),
-
                ('load-plugins',
                 {'type' : 'csv', 'metavar' : '<modules>', 'default' : (),
                  'help' : 'List of plugins (as comma separated values of \
@@ -318,8 +314,6 @@ This is used by the global evaluation report (R0004).'}),
                         meth(_id)
                 else :
                     meth(value)
-        elif opt_name == 'cache-size':
-            MANAGER.set_cache_size(int(value))
         elif opt_name == 'output-format':
             self.set_reporter(REPORTER_OPT_MAP[value.lower()]())
         elif opt_name in ('enable-checker', 'disable-checker'):
